import { Request, Response } from 'express';
import prisma from '@/utils/database';
import { ApiResponse } from '@/types';

export const healthCheck = async (req: Request, res: Response) => {
  try {
    await prisma.$queryRaw`SELECT 1`;
    
    const healthData = {
      status: 'healthy',
      timestamp: new Date().toISOString(),
      version: '1.0.0',
      services: {
        database: 'connected',
        api: 'running'
      }
    };

    return res.status(200).json({
      success: true,
      message: 'Service is healthy',
      data: healthData
    } as ApiResponse);

  } catch (error) {
    const healthData = {
      status: 'unhealthy',
      timestamp: new Date().toISOString(),
      version: '1.0.0',
      services: {
        database: 'disconnected',
        api: 'running'
      }
    };

    return res.status(503).json({
      success: false,
      message: 'Service is unhealthy',
      data: healthData
    } as ApiResponse);
  }
};